atomate.common.firetasks package — atomate 0.3 documentation

# atomate.common.firetasks package

## Subpackages

- atomate.common.firetasks.tests package
  - Submodules
  - atomate.common.firetasks.tests.test_glue_tasks module
  - Module contents

## Submodules

## atomate.common.firetasks.glue_tasks module

class `atomate.common.firetasks.glue_tasks.` `PassCalcLocs`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Passes the calc_locs key. Should be called in the same FireWork as a the calculation. This passes information about where the current run is located for the next FireWork.

  Required params:
    name: descriptive name for this calculation file/dir
  Optional params:

    filesystem: name of filesystem. Supports env_chk. defaults to None path: The path to the directory containing the calculation. defaults to

    > current working directory.

  `optional_params` = [u'filesystem', u'path']
  `required_params` = [u'name']
  `run_task`(fw_spec)

## atomate.common.firetasks.parse_outputs module

class `atomate.common.firetasks.parse_outputs.` `ToDbTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  General task to enter data from a calculation into the database. Can use any drone to parse the current directory into the DB file to insert.

  Required params:
    drone (AbstractDrone): Drone to convert the data to dict mmdb (MMDb): MMDb object
  Optional params:
    db_file (str): path to file containing the database credentials. Supports env_chk.
      Default: write data to JSON file (None).
    calc_dir (str): path to dir (on current filesystem) that contains calculation output files.
      Default: use current working directory.
    calc_loc (str OR bool): if True will set most recent calc_loc. If str search for the most
      recent calc_loc with the matching name

    options (dict): dict of options to pass into the Drone additional_fields (dict): dict of additional fields to add

  `optional_params` = [u'db_file', u'calc_dir', u'calc_loc', u'additional_fields', u'options']
  `required_params` = [u'drone', u'mmdb']
  `run_task`(fw_spec)

## Module contents